!---------------------------------------------------------------------------------------
! FLEXINVERT: read_reclist
!---------------------------------------------------------------------------------------
!  FLEXINVERT is free software: you can redistribute it and/or modify
!  it under the terms of the GNU General Public License as published by
!  the Free Software Foundation, either version 3 of the License, or
!  (at your option) any later version.
!
!  FLEXINVERT is distributed in the hope that it will be useful,
!  but WITHOUT ANY WARRANTY; without even the implied warranty of
!  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!  GNU General Public License for more details.
!
!  You should have received a copy of the GNU General Public License
!  along with FLEXINVERT.  If not, see <http://www.gnu.org/licenses/>.
!
!  Copyright 2017, Rona Thompson
!---------------------------------------------------------------------------------------
!
!> read_reclist
!!
!! Purpose:    Reads the receptor names from the receptor list.
!!
!---------------------------------------------------------------------------------------

subroutine read_reclist(config, filename)

  use mod_var
  use mod_settings
  use mod_strings

  implicit none

  type (config_t),             intent(in) :: config
  character(len=max_path_len), intent(in) :: filename
  character(len=max_path_len)             :: rowfmt
  character(len=200)                      :: line
  character(len=10)                       :: foo, sep
  integer                                 :: ierr
  integer                                 :: cnt, reclen

  ! count number of receptors

  nrec = 0
  open(100,file=trim(filename),action='read',status='old',iostat=ierr)
  if( ierr.gt.0.and..not.config%satellite ) then
    write(logid,*) 'ERROR: cannot open: '//trim(filename)
    stop
  else if ( ierr.gt.0.and.config%satellite ) then
    write(logid,*) 'WARNING: no ground-based observations found'
    go to 20
  endif
  write(logid,*) 'Reading receptors file: '//trim(filename)

  cnt = 0
  do while (ierr.eq.0)
    read(100,*,iostat=ierr,end=10) line
    call split(line," ",foo,sep)
    reclen = len_trim(foo)
    cnt = cnt + 1
  end do
10 continue
  close(100)

  nrec = cnt
  write(logid,*) 'Number of receptors: ',nrec

  ! read receptors

  allocate ( recname(nrec) )
  allocate ( reclon(nrec) )
  allocate ( reclat(nrec) )
  allocate ( recalt(nrec) )

  open(100,file=trim(filename),action='read',status='old',iostat=ierr)
  write(logid,*) 'Receptors: '

!  write(rowfmt,fmt='(A,I1,A)') '(A',recname_len,',1X,F7.2,1X,F7.2,1X,F7.2)'
  write(rowfmt,fmt='(A,I1,A)') '(A',3,',1X,F7.2,1X,F7.2,1X,F7.2)'
  do cnt = 1, nrec
    read(100,fmt=rowfmt) recname(cnt), reclat(cnt), reclon(cnt), recalt(cnt)
    write(logid,*) recname(cnt), reclat(cnt), reclon(cnt), recalt(cnt)
  end do

  close(100)

20 continue
 
end subroutine read_reclist


